'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var mplAuctionHouse = require('@metaplex-foundation/mpl-auction-house');
var AuctionsClient = require('./AuctionsClient.cjs');
var program = require('./program.cjs');
var createAuctionHouse = require('./createAuctionHouse.cjs');
var createListing = require('./createListing.cjs');
var findAuctionHouseByAddress = require('./findAuctionHouseByAddress.cjs');
var updateAuctionHouse = require('./updateAuctionHouse.cjs');
var loadListing = require('./loadListing.cjs');
var findListingByAddress = require('./findListingByAddress.cjs');

const auctionHouseModule = () => ({
  install(metaplex) {
    // Auction House Program.
    metaplex.programs().register({
      name: 'AuctionHouseProgram',
      address: program.AuctionHouseProgram.publicKey,
      errorResolver: error => mplAuctionHouse.cusper.errorFromProgramLogs(error.logs, false)
    });
    const op = metaplex.operations();
    op.register(createAuctionHouse.createAuctionHouseOperation, createAuctionHouse.createAuctionHouseOperationHandler);
    op.register(createListing.createListingOperation, createListing.createListingOperationHandler);
    op.register(findAuctionHouseByAddress.findAuctionHouseByAddressOperation, findAuctionHouseByAddress.findAuctionHouseByAddressOperationHandler);
    op.register(findListingByAddress.findListingByAddressOperation, findListingByAddress.findListingByAddressOperationHandler);
    op.register(loadListing.loadListingOperation, loadListing.loadListingOperationHandler);
    op.register(updateAuctionHouse.updateAuctionHouseOperation, updateAuctionHouse.updateAuctionHouseOperationHandler);

    metaplex.auctions = function () {
      return new AuctionsClient.AuctionsClient(this);
    };
  }

});

exports.auctionHouseModule = auctionHouseModule;
//# sourceMappingURL=plugin.cjs.map
